@@ -7,12 +7,11 @@ module Heist.Common where
 import           Control.Applicative
 import           Control.Exception (SomeException)
 import           Control.Monad
-import           Control.Monad.CatchIO
+import qualified Control.Monad.CatchIO as C
 import qualified Data.Attoparsec.Text            as AP
 import           Data.ByteString (ByteString)
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Char8 as BC
-import           Data.Either
 import           Data.Hashable
 import           Data.HashMap.Strict (HashMap)
 import qualified Data.HashMap.Strict as Map
@@ -20,8 +19,8 @@ import           Data.List
 import           Data.Maybe
 import           Data.Monoid
 import qualified Data.Text                       as T
-import           Prelude hiding (catch)
 import           System.FilePath
+import           Heist.SpliceAPI
 import           Heist.Types
 import qualified Text.XmlHtml as X
 
@@ -239,7 +238,7 @@ type ParserFun = String -> ByteString -> Either String X.Document
 -- | Reads an HTML or XML template from disk.
 getDocWith :: ParserFun -> String -> IO (Either String DocumentFile)
 getDocWith parser f = do
-    bs <- catch (liftM Right $ B.readFile f)
+    bs <- C.catch (liftM Right $ B.readFile f)
                 (\(e::SomeException) -> return $ Left $ show e)
 
     let eitherDoc = either Left (parser f) bs
@@ -291,10 +290,18 @@ mimeType d = case d of
 
 ------------------------------------------------------------------------------
 -- | Binds a set of new splice declarations within a 'HeistState'.
-bindAttributeSplices :: [(T.Text, AttrSplice n)] -- ^ splices to bind
-                     -> HeistState n             -- ^ start state
+bindAttributeSplices :: Splices (AttrSplice n) -- ^ splices to bind
+                     -> HeistState n           -- ^ start state
                      -> HeistState n
 bindAttributeSplices ss hs =
-    hs { _attrSpliceMap = Map.union (Map.fromList ss) (_attrSpliceMap hs) }
+    hs { _attrSpliceMap = Map.union (Map.fromList $ splicesToList ss)
+                                    (_attrSpliceMap hs) }
+
+
+------------------------------------------------------------------------------
+-- | Mappends a doctype to the state.
+addDoctype :: Monad m => [X.DocType] -> HeistT n m ()
+addDoctype dt = do
+    modifyHS (\s -> s { _doctypes = _doctypes s `mappend` dt })
 
 
